@@ -31,74 +31,72 @@ using namespace bt;
 
 namespace dht
 {
-	FindNodeRsp::FindNodeRsp()
-			: RPCMsg(QByteArray(), FIND_NODE, RSP_MSG, Key())
-	{
-	}
+FindNodeRsp::FindNodeRsp()
+    : RPCMsg(QByteArray(), FIND_NODE, RSP_MSG, Key())
+{
+}
 
-	FindNodeRsp::FindNodeRsp(const QByteArray & mtid, const Key & id)
-			: RPCMsg(mtid, FIND_NODE, RSP_MSG, id)
-	{}
+FindNodeRsp::FindNodeRsp(const QByteArray & mtid, const Key & id)
+    : RPCMsg(mtid, FIND_NODE, RSP_MSG, id)
+{}
 
-	FindNodeRsp::~FindNodeRsp() {}
+FindNodeRsp::~FindNodeRsp() {}
 
-	void FindNodeRsp::apply(dht::DHT* dh_table)
-	{
-		dh_table->response(*this);
-	}
+void FindNodeRsp::apply(dht::DHT* dh_table)
+{
+    dh_table->response(*this);
+}
 
-	void FindNodeRsp::print()
-	{
-		Out(SYS_DHT | LOG_DEBUG) << QString("RSP: %1 %2 : find_node")
-		.arg(mtid[0]).arg(id.toString()) << endl;
-	}
+void FindNodeRsp::print()
+{
+    Out(SYS_DHT | LOG_DEBUG) << QString("RSP: %1 %2 : find_node")
+                             .arg(mtid[0]).arg(id.toString()) << endl;
+}
 
-	void FindNodeRsp::encode(QByteArray & arr) const
-	{
-		BEncoder enc(new BEncoderBufferOutput(arr));
-		enc.beginDict();
-		{
-			enc.write(RSP); enc.beginDict();
-			{
-				enc.write(QByteArrayLiteral("id")); enc.write(id.getData(), 20);
-				if (nodes.size() > 0)
-				{
-					enc.write(QByteArrayLiteral("nodes")); 
-					enc.write(nodes);
-				}
-				
-				if (nodes6.size() > 0)
-				{
-					enc.write(QByteArrayLiteral("nodes6")); 
-					enc.write(nodes6);
-				}
-			}
-			enc.end();
-			enc.write(TID); enc.write(mtid);
-			enc.write(TYP); enc.write(RSP);
-		}
-		enc.end();
-	}
+void FindNodeRsp::encode(QByteArray & arr) const
+{
+    BEncoder enc(new BEncoderBufferOutput(arr));
+    enc.beginDict();
+    {
+        enc.write(RSP); enc.beginDict();
+        {
+            enc.write(QByteArrayLiteral("id")); enc.write(id.getData(), 20);
+            if (nodes.size() > 0) {
+                enc.write(QByteArrayLiteral("nodes"));
+                enc.write(nodes);
+            }
 
-	void FindNodeRsp::parse(BDictNode* dict)
-	{
-		dht::RPCMsg::parse(dict);
-		BDictNode* args = dict->getDict(RSP);
-		if (!args)
-			throw bt::Error("Invalid response, arguments missing");
+            if (nodes6.size() > 0) {
+                enc.write(QByteArrayLiteral("nodes6"));
+                enc.write(nodes6);
+            }
+        }
+        enc.end();
+        enc.write(TID); enc.write(mtid);
+        enc.write(TYP); enc.write(RSP);
+    }
+    enc.end();
+}
 
-		if (!args->getValue("nodes") && !args->getList("nodes6"))
-			throw bt::Error("Missing nodes or nodes6 parameter");
+void FindNodeRsp::parse(BDictNode* dict)
+{
+    dht::RPCMsg::parse(dict);
+    BDictNode* args = dict->getDict(RSP);
+    if (!args)
+        throw bt::Error("Invalid response, arguments missing");
+
+    if (!args->getValue("nodes") && !args->getList("nodes6"))
+        throw bt::Error("Missing nodes or nodes6 parameter");
 
 
-		BValueNode* v = args->getValue("nodes");
-		if (v)
-			nodes = v->data().toByteArray();
+    BValueNode* v = args->getValue("nodes");
+    if (v)
+        nodes = v->data().toByteArray();
 
-		v = args->getValue("nodes6");
-		if (v)
-			nodes6 = v->data().toByteArray();
-	}
+    v = args->getValue("nodes6");
+    if (v)
+        nodes6 = v->data().toByteArray();
+}
 
 }
 
