@@ -51,35 +51,28 @@ private Q_SLOTS:
         files["bbb.avi"] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
         files["ccc.avi"] = RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE);
 
-        try
-        {
+        try {
             QVERIFY(multi_creator.createMultiFileTorrent(files, "movies"));
             Out(SYS_GEN | LOG_DEBUG) << "Created " << multi_creator.torrentPath() << endl;
             multi_tor.load(bt::LoadFile(multi_creator.torrentPath()), false);
 
             // Truncate the files so we can preallocate them again
-            for (QMap<QString, bt::Uint64>::iterator i = files.begin(); i != files.end(); i++)
-            {
+            for (QMap<QString, bt::Uint64>::const_iterator i = files.cbegin(); i != files.cend(); i++) {
                 bt::TruncateFile(multi_creator.dataPath() + i.key(), 0);
             }
-        }
-        catch (bt::Error& err)
-        {
+        } catch (bt::Error& err) {
             Out(SYS_GEN | LOG_DEBUG) << "Failed to load torrent: " << multi_creator.torrentPath() << endl;
             QFAIL("Torrent load failure");
         }
 
-        try
-        {
+        try {
             QVERIFY(single_creator.createSingleFileTorrent(RandomSize(TEST_FILE_SIZE / 2, TEST_FILE_SIZE), "bla.avi"));
             Out(SYS_GEN | LOG_DEBUG) << "Created " << single_creator.torrentPath() << endl;
             single_tor.load(bt::LoadFile(single_creator.torrentPath()), false);
 
             // Truncate the file so we can preallocate them again
             bt::TruncateFile(single_creator.dataPath(), 0);
-        }
-        catch (bt::Error& err)
-        {
+        } catch (bt::Error& err) {
             Out(SYS_GEN | LOG_DEBUG) << "Failed to load torrent: " << single_creator.torrentPath() << endl;
             QFAIL("Torrent load failure");
         }
@@ -107,8 +100,7 @@ private Q_SLOTS:
         QVERIFY(prealloc.errorHappened() == false);
         QVERIFY(prealloc.bytesWritten() == multi_tor.getTotalSize());
 
-        for (bt::Uint32 i = 0; i < multi_tor.getNumFiles(); i++)
-        {
+        for (bt::Uint32 i = 0; i < multi_tor.getNumFiles(); i++) {
             QVERIFY(bt::FileSize(multi_tor.getFile(i).getPathOnDisk()) == multi_tor.getFile(i).getSize());
         }
     }
