@@ -2,9 +2,11 @@
 #define QT_GUI_LIB
 #endif
 
-#include <QtTest>
 #include <QObject>
 #include <QLocale>
+#include <QRandomGenerator>
+#include <QtTest>
+
 #include <unistd.h>
 #include <ctime>
 #include <util/log.h>
@@ -17,7 +19,6 @@
 #include <interfaces/queuemanagerinterface.h>
 
 
-
 using namespace bt;
 
 const bt::Uint32 TEST_FILE_SIZE = 5 * 1024 * 1024;
@@ -52,29 +53,22 @@ private Q_SLOTS:
 
         Out(SYS_GEN | LOG_DEBUG) << "Created " << creator.torrentPath() << endl;
         Out(SYS_GEN | LOG_DEBUG) << "Created " << creator2.torrentPath() << endl;
-        try
-        {
+        try {
             tc.init(this, bt::LoadFile(creator.torrentPath()), creator.tempPath() + "tor0", creator.tempPath() + "data/");
             tc.createFiles();
             QVERIFY(tc.hasExistingFiles());
             tc.startDataCheck(false, 0, tc.getStats().total_chunks);
-            do
-            {
+            do {
                 processEvents(AllEvents, 1000);
-            }
-            while (tc.getStats().status == bt::CHECKING_DATA);
+            } while (tc.getStats().status == bt::CHECKING_DATA);
             QVERIFY(tc.getStats().completed);
 
             incomplete_tc.init(this, bt::LoadFile(creator2.torrentPath()), creator2.tempPath() + "tor0", creator2.tempPath() + "data/");
             incomplete_tc.createFiles();
-        }
-        catch (bt::Error& err)
-        {
+        } catch (bt::Error& err) {
             Out(SYS_GEN | LOG_DEBUG) << "Failed to load torrent: " << creator.torrentPath() << endl;
             QFAIL("Torrent load failure");
         }
-
-        qsrand(time(0));
     }
 
     void cleanupTestCase()
@@ -92,8 +86,7 @@ private Q_SLOTS:
         QByteArray tmp(tc.getStats().chunk_size, 0);
         bt::Uint64 written = 0;
         bt::Uint32 idx = 0;
-        while (written < TEST_FILE_SIZE)
-        {
+        while (written < TEST_FILE_SIZE) {
             qint64 ret = stream->read(tmp.data(), tc.getStats().chunk_size);
             QVERIFY(ret == tc.getStats().chunk_size);
             written += tc.getStats().chunk_size;
@@ -120,20 +113,18 @@ private Q_SLOTS:
         QByteArray tmp(chunk_size, 0);
         bt::Uint64 written = 0;
         bt::Uint32 idx = 0;
-        while (written < TEST_FILE_SIZE)
-        {
+        while (written < TEST_FILE_SIZE) {
             // Chunk size of last chunk can be smaller
-            if (idx == tc.getStats().total_chunks - 1)
-            {
+            if (idx == tc.getStats().total_chunks - 1) {
                 chunk_size = tc.getStats().chunk_size % tc.getStats().total_bytes;
                 if (chunk_size == 0)
                     chunk_size = tc.getStats().chunk_size;
             }
 
             // Lets read in two times, first at the back and then at the front
-            qint64 split = qrand() % chunk_size;
+            qint64 split = QRandomGenerator::global()->bounded(chunk_size);
             while (split == 0)
-                split = qrand() % chunk_size;
+                split = QRandomGenerator::global()->bounded(chunk_size);
 
             QVERIFY(stream->seek(idx * tc.getStats().chunk_size + split));
             qint64 ret = stream->read(tmp.data() + split, chunk_size - split);
@@ -166,7 +157,7 @@ private Q_SLOTS:
         // Read an area of around 5 chunks in at a random location
         // And verify the 3 middle chunks
         qint64 range_size = tc.getStats().chunk_size * 5;
-        qint64 off = ((qrand() % 100) / 100.0) * (tc.getStats().total_bytes - range_size);
+        qint64 off = QRandomGenerator::global()->bounded(100) / 100.0 * (tc.getStats().total_bytes - range_size);
         QVERIFY(stream->seek(off));
 
         Out(SYS_GEN | LOG_DEBUG) << "Reading random range" << endl;
@@ -175,8 +166,7 @@ private Q_SLOTS:
 
         QByteArray range(range_size, 0);
         qint64 bytes_read = 0;
-        while (bytes_read < range_size)
-        {
+        while (bytes_read < range_size) {
             qint64 ret = stream->read(range.data() + bytes_read, range_size - bytes_read);
             Out(SYS_GEN | LOG_DEBUG) << "ret = " << ret << endl;
             Out(SYS_GEN | LOG_DEBUG) << "read = " << bytes_read << endl;
@@ -207,8 +197,7 @@ private Q_SLOTS:
 
 
         // Verify the hashes
-        for (int i = 0; i < 3; i++)
-        {
+        for (int i = 0; i < 3; i++) {
             bt::SHA1Hash hash = bt::SHA1Hash::generate((const bt::Uint8*)range.data() + chunk_off, tc.getStats().chunk_size);
 
             Out(SYS_GEN | LOG_DEBUG) << "chash = " << hash.toString() << endl;
@@ -232,9 +221,8 @@ private Q_SLOTS:
 
         QFile fptr(stream->path());
         QVERIFY(fptr.open(QIODevice::ReadOnly));
-        for (int i = 0; i < 20; i++)
-        {
-            qint64 off = qrand() % (TEST_FILE_SIZE - 100);
+        for (int i = 0; i < 20; i++) {
+            qint64 off = QRandomGenerator::global()->bounded(TEST_FILE_SIZE - 100);
             // Seek to a random location
             QVERIFY(stream->seek(off));
             QByteArray tmp(100, 0);
